@@ -2,7 +2,6 @@ from graia.application.event.messages import GroupMessage
 from graia.application.message.chain import MessageChain
 from graia.application.message.elements.internal import Plain, Source
 from graia.application.group import Group, Member
-from graia.application import GraiaMiraiApplication
 
 from graia.saya import Saya, Channel
 from graia.saya.builtins.broadcast.schema import ListenerSchema
@@ -19,7 +18,7 @@ channel = Channel.current()
     listening_events=[GroupMessage] # 填入你需要监听的事件
 ))
 @db_session
-async def record(app: GraiaMiraiApplication, group: Group, member: Member, messageChain: MessageChain):
+async def record(group: Group, member: Member, messageChain: MessageChain):
     if messageChain.has(Plain):
         messageTables.GroupMessage(
             groupId=str(group.id), 
