@@ -2,6 +2,8 @@ import os
 from pony.orm import *
 from datetime import datetime
 
+from . import db_filepath
+
 
 db = Database()
 
@@ -12,9 +14,5 @@ class GroupMessage(db.Entity):
     memberId = Required(str) # 成员 QQ 号
     plain = Required(str) # 消息的文本内容
 
-
-db_filepath = os.path.join(os.getcwd(), "dbFile")
-if not os.path.exists(db_filepath):
-    os.mkdir(db_filepath)
 db.bind(provider='sqlite', filename=os.path.join(db_filepath, "messageTables.sqlite"), create_db=True)
 db.generate_mapping(create_tables=True)
\ No newline at end of file
